[QGIS Commit] r12621 - trunk/qgis/python/plugins/plugin_installer

svn_qgis at osgeo.org svn_qgis at osgeo.org
Sat Dec 26 18:37:50 EST 2009


Author: borysiasty
Date: 2009-12-26 18:37:48 -0500 (Sat, 26 Dec 2009)
New Revision: 12621

Modified:
   trunk/qgis/python/plugins/plugin_installer/__init__.py
   trunk/qgis/python/plugins/plugin_installer/installer_gui.py
   trunk/qgis/python/plugins/plugin_installer/installer_plugin.py
Log:
plugin installer update - fix #2247

Modified: trunk/qgis/python/plugins/plugin_installer/__init__.py
===================================================================
--- trunk/qgis/python/plugins/plugin_installer/__init__.py	2009-12-26 12:50:54 UTC (rev 12620)
+++ trunk/qgis/python/plugins/plugin_installer/__init__.py	2009-12-26 23:37:48 UTC (rev 12621)
@@ -15,7 +15,7 @@
   return "Plugin Installer"
 
 def version():
-  return "Version 1.0.7"
+  return "Version 1.0.8"
 
 def description():
   return "Downloads and installs QGIS python plugins"

Modified: trunk/qgis/python/plugins/plugin_installer/installer_gui.py
===================================================================
--- trunk/qgis/python/plugins/plugin_installer/installer_gui.py	2009-12-26 12:50:54 UTC (rev 12620)
+++ trunk/qgis/python/plugins/plugin_installer/installer_gui.py	2009-12-26 23:37:48 UTC (rev 12621)
@@ -311,10 +311,14 @@
       for key in repositories.all():
         repositories.killConnection(key)
 
-    # display error messages for every unavailable reposioty, except the case if all repositories are unavailable!
+    # display error messages for every unavailable reposioty, unless Shift pressed nor all repositories are unavailable
+    keepQuiet = QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier)
     if repositories.allUnavailable() and repositories.allUnavailable() != repositories.allEnabled():
       for key in repositories.allUnavailable():
-        QMessageBox.warning(self, self.tr("QGIS Python Plugin Installer"), self.tr("Error reading repository:") + " " + key + "\n" + repositories.all()[key]["error"])
+        if not keepQuiet:
+          QMessageBox.warning(self, self.tr("QGIS Python Plugin Installer"), self.tr("Error reading repository:") + " " + key + "\n" + repositories.all()[key]["error"])
+        if QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
+          keepQuiet = True
 
 
   # ----------------------------------------- #

Modified: trunk/qgis/python/plugins/plugin_installer/installer_plugin.py
===================================================================
--- trunk/qgis/python/plugins/plugin_installer/installer_plugin.py	2009-12-26 12:50:54 UTC (rev 12620)
+++ trunk/qgis/python/plugins/plugin_installer/installer_plugin.py	2009-12-26 23:37:48 UTC (rev 12621)
@@ -157,10 +157,14 @@
 
     QApplication.restoreOverrideCursor()
 
-    # display an error message for every unavailable reposioty, except the case if all repositories are unavailable!
+    # display error messages for every unavailable reposioty, unless Shift pressed nor all repositories are unavailable
+    keepQuiet = QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier)
     if repositories.allUnavailable() and repositories.allUnavailable() != repositories.allEnabled():
       for key in repositories.allUnavailable():
-        QMessageBox.warning(parent, QCoreApplication.translate("QgsPluginInstaller","QGIS Python Plugin Installer"), QCoreApplication.translate("QgsPluginInstaller","Error reading repository:") + QString(' %s\n%s' % (key,repositories.all()[key]["error"])))
+        if not keepQuiet:
+          QMessageBox.warning(parent, QCoreApplication.translate("QgsPluginInstaller","QGIS Python Plugin Installer"), QCoreApplication.translate("QgsPluginInstaller","Error reading repository:") + QString(' %s\n%s' % (key,repositories.all()[key]["error"])))
+        if QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
+          keepQuiet = True
 
     flags = Qt.WindowTitleHint | Qt.WindowSystemMenuHint | Qt.WindowMaximizeButtonHint 
     self.guiDlg = QgsPluginInstallerDialog(parent,flags)



More information about the QGIS-commit mailing list